==> mingw-w64-freecad-1.0rc2-3.src.tar.zst: FreeCAD-1.0rc2/src/Mod/Help/Resources/translations/Help_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr" sourcelanguage="en">
  <context>
    <name>Form</name>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="14"/>
      <source>Help</source>
      <translation>Pomoć</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="20"/>
      <source>Source</source>
      <translation>Izvor</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="46"/>
      <location filename="../../dlgPreferencesHelp.ui" line="86"/>
      <source>Set this to a custom URL or the folder where the help files are located.
You can easily download the documentation for offline use by using the Addon
Manager and installing the &quot;offline-documentation&quot; addon. If this
field is left blank, FreeCAD will automatically search for the help files at
the default location ($USERAPPDATADIR/Mod/offline-documentation).</source>
      <translation>Postavite ovo na prilagođeni URL ili mapu gdje se nalaze datoteke pomoći.
Lako možete preuzeti dokumentaciju za korištenje izvan mreže pomoću
Upravitelja Dodataka i instaliranjem dodatka &quot;offline dokumentacija&amp;quot.
Ako je ovo polje prazno, FreeCAD će automatski pretraživati datoteke za pomoć na
zadanoj lokaciji ($USERAPPDATADIR/Mod/offline-documentation).</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="53"/>
      <source>Custom location</source>
      <translation>Prilagođena lokacija</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="112"/>
      <source>    Translation suffix:</source>
      <translation>    Sufiks prijevoda:</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="123"/>
      <source>FreeCAD Wiki (online)</source>
      <translation>FreeCAD Wiki (online)</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="29"/>
      <source>This will fetch the documentation from pages rendered on GitHub.
This is currently not available...</source>
      <translation>Ovo će preuzeti dokumentaciju sa stranica iscrtanih na GitHub-u. To trenutno nije dostupno....</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="33"/>
      <source>GitHub (online)</source>
      <translation>GitHub (online)</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="72"/>
      <source>A translation suffix to use, for example &quot;fr&quot;
to get French translation of the documentation.</source>
      <translation>Sufiks prijevoda koji se koristi, na primjer &quot;hr&quot;
za hrvatski prijevod dokumentacije.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="119"/>
      <source>The documentation pages will be fetched from the official
FreeCADwiki at https://wiki.freecad.org</source>
      <translation>Dokumentacijske stranice će se preuzimati s službenog Wiki-ja FreeCAD-a na https://wiki.freecad.org</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="139"/>
      <source>The documentation pages will be fetched from an automatic Markdown conversion
of the FreeCAD wiki,hosted on FreeCAD&apos;s GitHub account. This can be styled with a
custom stylesheet below and can look nicer than the wiki option. The &apos;Markdown&apos; or
&apos;Pandoc&apos; Python module should be installed for optimal results.</source>
      <translation>Dokumentacijske stranice će se preuzimati iz automatskog pretvaranja FreeCAD wikija u Markdown, koje se nalazi na GitHub računu FreeCAD-a. To se može stilizirati pomoću prilagođenog stilskog predloška u nastavku i može izgledati ljepše od opcije wiki-ja. Modul Python &quot;Markdown&quot; ili &quot;Pandoc&quot; trebao bi biti instaliran za optimalne rezultate.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="145"/>
      <source>Markdown version (online)</source>
      <translation>Markdown verzija (online)</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="164"/>
      <source>Display</source>
      <translation>Prikaz</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="170"/>
      <source>Note: if PySide Web components are not found on your system, help pages will open in your default web browser regardless of the options below</source>
      <translation type="unfinished">Note: if PySide Web components are not found on your system, help pages will open in your default web browser regardless of the options below</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="202"/>
      <source>In a FreeCAD tab</source>
      <translation>U FreeCAD tab-u</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="180"/>
      <source>The documentation will open in your default web browser.</source>
      <translation>Dokumentacija će se otvoriti u vašem zadanom pregledniku.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="221"/>
      <source>The documentation will open in a dockable dialog inside the FreeCAD window,
which allows you to keep it open while working in the 3D view. This requires the PySide QtWebengineWidgets component</source>
      <translation type="unfinished">The documentation will open in a dockable dialog inside the FreeCAD window,
which allows you to keep it open while working in the 3D view. This requires the PySide QtWebengineWidgets component</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="256"/>
      <source>You can here indicate the path to an alternative CSS file to be used
to style the Markdown pages. This will only work if you have selected the
Markdown version above.</source>
      <translation>Ovdje možete navesti putanju do alternativne CSS datoteke
koja će se koristiti za oblikovanje stranica Markdowna.
Ova opcija će raditi samo ako ste odabrali Markdown verziju gore.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="183"/>
      <source>In your default web browser</source>
      <translation>U vašem zadanom web pregledniku</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="199"/>
      <source>The documentation will open in a new tab inside the FreeCAD interface. This requires the PySide QtWebengineWidgets component</source>
      <translation type="unfinished">The documentation will open in a new tab inside the FreeCAD interface. This requires the PySide QtWebengineWidgets component</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="225"/>
      <source>In a separate, embeddable dialog</source>
      <translation>U odvojenom, ugrađenom dijalogu</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="241"/>
      <source>Options</source>
      <translation>Mogućnosti</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="249"/>
      <source>      Custom stylesheet:</source>
      <translation>      Prilagođena tablice stilova:</translation>
    </message>
  </context>
  <context>
    <name>Help</name>
    <message>
      <location filename="../../Help.py" line="75"/>
      <source>Contents for this page could not be retrieved. Please check settings under menu Edit -&gt; Preferences -&gt; General -&gt; Help</source>
      <translation>Sadržaj ove stranice nije moguće preuzeti. Molimo provjerite postavke u izborniku Uredi -&gt; Postavke -&gt; Opće -&gt; Pomoć.</translation>
    </message>
    <message>
      <location filename="../../Help.py" line="79"/>
      <source>Help files location could not be determined. Please check settings under menu Edit -&gt; Preferences -&gt; General -&gt; Help</source>
      <translation>Mjesto datoteka za pomoć ne može se odrediti.. Molimo provjerite postavke u izborniku Uredi -&gt; Postavke -&gt; Opće -&gt; Pomoć.</translation>
    </message>
    <message>
      <location filename="../../Help.py" line="83"/>
      <source>PySide QtWebEngineWidgets module is not available. Help rendering is done with the system browser</source>
      <translation type="unfinished">PySide QtWebEngineWidgets module is not available. Help rendering is done with the system browser</translation>
    </message>
    <message>
      <location filename="../../Help.py" line="87"/>
      <source>There is no Markdown renderer installed on your system, so this help page is rendered as is. Please install the Markdown or Pandoc Python modules to improve the rendering of this page.</source>
      <translation type="unfinished">There is no Markdown renderer installed on your system, so this help page is rendered as is. Please install the Markdown or Pandoc Python modules to improve the rendering of this page.</translation>
    </message>
    <message>
      <location filename="../../Help.py" line="119"/>
      <source>Help</source>
      <translation>Pomoć</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Help.py" line="425"/>
      <source>General</source>
      <translation>Općenito</translation>
    </message>
  </context>
</TS>

==> mingw-w64-freecad-1.0.0-3.src.tar.zst: FreeCAD-1.0.0/src/Mod/Help/Resources/translations/Help_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr" sourcelanguage="en">
  <context>
    <name>Form</name>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="14"/>
      <source>Help</source>
      <translation>Pomoć</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="20"/>
      <source>Source</source>
      <translation>Izvor</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="46"/>
      <location filename="../../dlgPreferencesHelp.ui" line="86"/>
      <source>Set this to a custom URL or the folder where the help files are located.
You can easily download the documentation for offline use by using the Addon
Manager and installing the &quot;offline-documentation&quot; addon. If this
field is left blank, FreeCAD will automatically search for the help files at
the default location ($USERAPPDATADIR/Mod/offline-documentation).</source>
      <translation>Postavite ovo na prilagođeni URL ili mapu gdje se nalaze datoteke pomoći. 
Lako možete preuzeti dokumentaciju za korištenje izvan mreže pomoću 
Upravitelja Dodataka i instaliranjem dodatka &quot;offline dokumentacija&amp;quot. 
Ako je ovo polje prazno, FreeCAD će automatski pretraživati datoteke za pomoć na 
zadanoj lokaciji ($USERAPPDATADIR/Mod/offline-documentation).</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="53"/>
      <source>Custom location</source>
      <translation>Prilagođena lokacija</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="112"/>
      <source>    Translation suffix:</source>
      <translation>    Sufiks prijevoda:</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="123"/>
      <source>FreeCAD Wiki (online)</source>
      <translation>FreeCAD Wiki (online)</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="29"/>
      <source>This will fetch the documentation from pages rendered on GitHub.
This is currently not available...</source>
      <translation>Ovo će preuzeti dokumentaciju sa stranica iscrtanih na GitHub-u. To trenutno nije dostupno....</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="33"/>
      <source>GitHub (online)</source>
      <translation>GitHub (online)</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="72"/>
      <source>A translation suffix to use, for example &quot;fr&quot;
to get French translation of the documentation.</source>
      <translation>Sufiks prijevoda koji se koristi, na primjer &quot;hr&quot;
za hrvatski prijevod dokumentacije.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="119"/>
      <source>The documentation pages will be fetched from the official
FreeCADwiki at https://wiki.freecad.org</source>
      <translation>Dokumentacijske stranice će se preuzimati s službenog Wiki-ja FreeCAD-a na https://wiki.freecad.org</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="139"/>
      <source>The documentation pages will be fetched from an automatic Markdown conversion
of the FreeCAD wiki,hosted on FreeCAD&apos;s GitHub account. This can be styled with a
custom stylesheet below and can look nicer than the wiki option. The &apos;Markdown&apos; or
&apos;Pandoc&apos; Python module should be installed for optimal results.</source>
      <translation>Dokumentacijske stranice će se preuzimati iz automatskog pretvaranja FreeCAD wikija u Markdown, koje se nalazi na GitHub računu FreeCAD-a. To se može stilizirati pomoću prilagođenog stilskog predloška u nastavku i može izgledati ljepše od opcije wiki-ja. Modul Python &quot;Markdown&quot; ili &quot;Pandoc&quot; trebao bi biti instaliran za optimalne rezultate.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="145"/>
      <source>Markdown version (online)</source>
      <translation>Markdown verzija (online)</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="164"/>
      <source>Display</source>
      <translation>Prikaz</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="170"/>
      <source>Note: if PySide Web components are not found on your system, help pages will open in your default web browser regardless of the options below</source>
      <translation>Napomena: ako PySide web komponente nisu pronađene na vašem sustavu, stranice pomoći će se otvoriti u vašem zadanom web pregledniku bez obzira na opcije ispod</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="202"/>
      <source>In a FreeCAD tab</source>
      <translation>U FreeCAD tab-u</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="180"/>
      <source>The documentation will open in your default web browser.</source>
      <translation>Dokumentacija će se otvoriti u vašem zadanom pregledniku.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="221"/>
      <source>The documentation will open in a dockable dialog inside the FreeCAD window,
which allows you to keep it open while working in the 3D view. This requires the PySide QtWebengineWidgets component</source>
      <translation>Dokumentacija će se otvoriti u Ugrađenom dijalogu koji se može pohraniti u prozoru FreeCAD-a, 
što vam omogućuje da ga držite otvorenim dok radite u 3D prikazu.Ovo zahtijeva komponentu PySide QtWebengineWidgets</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="256"/>
      <source>You can here indicate the path to an alternative CSS file to be used
to style the Markdown pages. This will only work if you have selected the
Markdown version above.</source>
      <translation>Ovdje možete navesti putanju do alternativne CSS datoteke 
koja će se koristiti za oblikovanje stranica Markdowna. 
Ova opcija će raditi samo ako ste odabrali Markdown verziju gore.</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="183"/>
      <source>In your default web browser</source>
      <translation>U vašem zadanom web pregledniku</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="199"/>
      <source>The documentation will open in a new tab inside the FreeCAD interface. This requires the PySide QtWebengineWidgets component</source>
      <translation>Dokumentacija će se otvoriti u novoj kartici unutar FreeCAD sučelja. Ovo zahtijeva komponentu PySide QtWebengineWidgets</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="225"/>
      <source>In a separate, embeddable dialog</source>
      <translation>U odvojenom, ugrađenom dijalogu</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="241"/>
      <source>Options</source>
      <translation>Mogućnosti</translation>
    </message>
    <message>
      <location filename="../../dlgPreferencesHelp.ui" line="249"/>
      <source>      Custom stylesheet:</source>
      <translation>      Prilagođena tablice stilova:</translation>
    </message>
  </context>
  <context>
    <name>Help</name>
    <message>
      <location filename="../../Help.py" line="75"/>
      <source>Contents for this page could not be retrieved. Please check settings under menu Edit -&gt; Preferences -&gt; General -&gt; Help</source>
      <translation>Sadržaj ove stranice nije moguće preuzeti. Molimo provjerite postavke u izborniku Uredi -&gt; Postavke -&gt; Opće -&gt; Pomoć.</translation>
    </message>
    <message>
      <location filename="../../Help.py" line="79"/>
      <source>Help files location could not be determined. Please check settings under menu Edit -&gt; Preferences -&gt; General -&gt; Help</source>
      <translation>Mjesto datoteka za pomoć ne može se odrediti.. Molimo provjerite postavke u izborniku Uredi -&gt; Postavke -&gt; Opće -&gt; Pomoć.</translation>
    </message>
    <message>
      <location filename="../../Help.py" line="83"/>
      <source>PySide QtWebEngineWidgets module is not available. Help rendering is done with the system browser</source>
      <translation>PySide QtWebEngineWidgets modul nije dostupan. Prikazivanje pomoći vrši se preglednikom sustava</translation>
    </message>
    <message>
      <location filename="../../Help.py" line="87"/>
      <source>There is no Markdown renderer installed on your system, so this help page is rendered as is. Please install the Markdown or Pandoc Python modules to improve the rendering of this page.</source>
      <translation>Na vašem sustavu nije instaliran Markdown renderer, pa se ova stranica pomoći prikazuje kakva jest. Instalirajte module Markdown ili Pandoc Python kako biste poboljšali prikaz ove stranice.</translation>
    </message>
    <message>
      <location filename="../../Help.py" line="119"/>
      <source>Help</source>
      <translation>Pomoć</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Help.py" line="432"/>
      <source>General</source>
      <translation>Općenito</translation>
    </message>
  </context>
</TS>
